| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.MediaStore.CreateContainer
Description
Creates a storage container to hold objects. A container is similar to a bucket in the Amazon S3 service.
- createContainer :: Text -> CreateContainer
- data CreateContainer
- ccContainerName :: Lens' CreateContainer Text
- createContainerResponse :: Int -> Container -> CreateContainerResponse
- data CreateContainerResponse
- ccrsResponseStatus :: Lens' CreateContainerResponse Int
- ccrsContainer :: Lens' CreateContainerResponse Container
Creating a Request
Arguments
| :: Text | |
| -> CreateContainer |
Creates a value of CreateContainer with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ccContainerName- The name for the container. The name must be from 1 to 255 characters. Container names must be unique to your AWS account within a specific region. As an example, you could create a container namedmoviesin every region, as long as you don’t have an existing container with that name.
data CreateContainer Source #
See: createContainer smart constructor.
Instances
Request Lenses
ccContainerName :: Lens' CreateContainer Text Source #
The name for the container. The name must be from 1 to 255 characters. Container names must be unique to your AWS account within a specific region. As an example, you could create a container named movies in every region, as long as you don’t have an existing container with that name.
Destructuring the Response
createContainerResponse Source #
Arguments
| :: Int | |
| -> Container | |
| -> CreateContainerResponse |
Creates a value of CreateContainerResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ccrsResponseStatus- -- | The response status code.ccrsContainer- ContainerARN: The Amazon Resource Name (ARN) of the newly created container. The ARN has the following format: arn:aws:region:that owns this container:containerof container. For example: arn:aws:mediastore:us-west-2:111122223333:containermovies ContainerName: The container name as specified in the request. CreationTime: Unix time stamp. Status: The status of container creation or deletion. The status is one of the following:CREATING,ACTIVE, orDELETING. While the service is creating the container, the status isCREATING. When an endpoint is available, the status changes toACTIVE. The return value does not include the container's endpoint. To make downstream requests, you must obtain this value by usingDescribeContainerorListContainers.
data CreateContainerResponse Source #
See: createContainerResponse smart constructor.
Response Lenses
ccrsResponseStatus :: Lens' CreateContainerResponse Int Source #
- - | The response status code.
ccrsContainer :: Lens' CreateContainerResponse Container Source #
ContainerARN: The Amazon Resource Name (ARN) of the newly created container. The ARN has the following format: arn:aws:region:that owns this container:containerof container. For example: arn:aws:mediastore:us-west-2:111122223333:containermovies ContainerName: The container name as specified in the request. CreationTime: Unix time stamp. Status: The status of container creation or deletion. The status is one of the following: CREATING , ACTIVE , or DELETING . While the service is creating the container, the status is CREATING . When an endpoint is available, the status changes to ACTIVE . The return value does not include the container's endpoint. To make downstream requests, you must obtain this value by using DescribeContainer or ListContainers .