| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.MediaStore.ListContainers
Description
Lists the properties of all containers in AWS Elemental MediaStore.
You can query to receive all the containers in one response. Or you can include the MaxResults parameter to receive a limited number of containers in each response. In this case, the response includes a token. To get the next set of containers, send the command again, this time with the NextToken parameter (with the returned token as its value). The next set of responses appears, with a token if there are still more containers to receive.
See also DescribeContainer , which gets the properties of one container.
- listContainers :: ListContainers
- data ListContainers
- lcNextToken :: Lens' ListContainers (Maybe Text)
- lcMaxResults :: Lens' ListContainers (Maybe Natural)
- listContainersResponse :: Int -> ListContainersResponse
- data ListContainersResponse
- lcrsNextToken :: Lens' ListContainersResponse (Maybe Text)
- lcrsResponseStatus :: Lens' ListContainersResponse Int
- lcrsContainers :: Lens' ListContainersResponse [Container]
Creating a Request
listContainers :: ListContainers Source #
Creates a value of ListContainers with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lcNextToken- Only if you usedMaxResultsin the first command, enter the token (which was included in the previous response) to obtain the next set of containers. This token is included in a response only if there actually are more containers to list.lcMaxResults- Enter the maximum number of containers in the response. Use from 1 to 255 characters.
data ListContainers Source #
See: listContainers smart constructor.
Instances
Request Lenses
lcNextToken :: Lens' ListContainers (Maybe Text) Source #
Only if you used MaxResults in the first command, enter the token (which was included in the previous response) to obtain the next set of containers. This token is included in a response only if there actually are more containers to list.
lcMaxResults :: Lens' ListContainers (Maybe Natural) Source #
Enter the maximum number of containers in the response. Use from 1 to 255 characters.
Destructuring the Response
listContainersResponse Source #
Arguments
| :: Int | |
| -> ListContainersResponse |
Creates a value of ListContainersResponse with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
lcrsNextToken-NextTokenis the token to use in the next call toListContainers. This token is returned only if you included theMaxResultstag in the original command, and only if there are still containers to return.lcrsResponseStatus- -- | The response status code.lcrsContainers- The names of the containers.
data ListContainersResponse Source #
See: listContainersResponse smart constructor.
Response Lenses
lcrsNextToken :: Lens' ListContainersResponse (Maybe Text) Source #
NextToken is the token to use in the next call to ListContainers . This token is returned only if you included the MaxResults tag in the original command, and only if there are still containers to return.
lcrsResponseStatus :: Lens' ListContainersResponse Int Source #
- - | The response status code.
lcrsContainers :: Lens' ListContainersResponse [Container] Source #
The names of the containers.