| Copyright | (c) 2013-2018 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay+amazonka@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.MediaStore.Types
Description
- mediaStore :: Service
- _PolicyNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError
- _CORSPolicyNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError
- _ContainerInUseException :: AsError a => Getting (First ServiceError) a ServiceError
- _InternalServerError :: AsError a => Getting (First ServiceError) a ServiceError
- _ContainerNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError
- _LimitExceededException :: AsError a => Getting (First ServiceError) a ServiceError
- data ContainerStatus
- data MethodName
- data CORSRule
- corsRule :: CORSRule
- crAllowedMethods :: Lens' CORSRule [MethodName]
- crMaxAgeSeconds :: Lens' CORSRule (Maybe Natural)
- crAllowedHeaders :: Lens' CORSRule [Text]
- crAllowedOrigins :: Lens' CORSRule [Text]
- crExposeHeaders :: Lens' CORSRule [Text]
- data Container
- container :: Container
- cCreationTime :: Lens' Container (Maybe UTCTime)
- cStatus :: Lens' Container (Maybe ContainerStatus)
- cARN :: Lens' Container (Maybe Text)
- cName :: Lens' Container (Maybe Text)
- cEndpoint :: Lens' Container (Maybe Text)
Service Configuration
mediaStore :: Service Source #
API version 2017-09-01 of the Amazon Elemental MediaStore SDK configuration.
Errors
_PolicyNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError Source #
Could not perform an operation on a policy that does not exist.
_CORSPolicyNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError Source #
Could not perform an operation on a policy that does not exist.
_ContainerInUseException :: AsError a => Getting (First ServiceError) a ServiceError Source #
Resource already exists or is being updated.
_InternalServerError :: AsError a => Getting (First ServiceError) a ServiceError Source #
The service is temporarily unavailable.
_ContainerNotFoundException :: AsError a => Getting (First ServiceError) a ServiceError Source #
Could not perform an operation on a container that does not exist.
_LimitExceededException :: AsError a => Getting (First ServiceError) a ServiceError Source #
A service limit has been exceeded.
ContainerStatus
data ContainerStatus Source #
Instances
MethodName
data MethodName Source #
Instances
CORSRule
A rule for a CORS policy. You can add up to 100 rules to a CORS policy. If more than one rule applies, the service uses the first applicable rule listed.
See: corsRule smart constructor.
Creates a value of CORSRule with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
crAllowedMethods- Identifies an HTTP method that the origin that is specified in the rule is allowed to execute. Each CORS rule must contain at least oneAllowedMethodand oneAllowedOriginelement.crMaxAgeSeconds- The time in seconds that your browser caches the preflight response for the specified resource. A CORS rule can have only oneMaxAgeSecondselement.crAllowedHeaders- Specifies which headers are allowed in a preflightOPTIONSrequest through theAccess-Control-Request-Headersheader. Each header name that is specified inAccess-Control-Request-Headersmust have a corresponding entry in the rule. Only the headers that were requested are sent back. This element can contain only one wildcard character (*).crAllowedOrigins- One or more response headers that you want users to be able to access from their applications (for example, from a JavaScriptXMLHttpRequestobject). Each CORS rule must have at least oneAllowedOriginelement. The string value can include only one wildcard character (*), for example, http://*.example.com. Additionally, you can specify only one wildcard character to allow cross-origin access for all origins.crExposeHeaders- One or more headers in the response that you want users to be able to access from their applications (for example, from a JavaScriptXMLHttpRequestobject). This element is optional for each rule.
crAllowedMethods :: Lens' CORSRule [MethodName] Source #
Identifies an HTTP method that the origin that is specified in the rule is allowed to execute. Each CORS rule must contain at least one AllowedMethod and one AllowedOrigin element.
crMaxAgeSeconds :: Lens' CORSRule (Maybe Natural) Source #
The time in seconds that your browser caches the preflight response for the specified resource. A CORS rule can have only one MaxAgeSeconds element.
crAllowedHeaders :: Lens' CORSRule [Text] Source #
Specifies which headers are allowed in a preflight OPTIONS request through the Access-Control-Request-Headers header. Each header name that is specified in Access-Control-Request-Headers must have a corresponding entry in the rule. Only the headers that were requested are sent back. This element can contain only one wildcard character (*).
crAllowedOrigins :: Lens' CORSRule [Text] Source #
One or more response headers that you want users to be able to access from their applications (for example, from a JavaScript XMLHttpRequest object). Each CORS rule must have at least one AllowedOrigin element. The string value can include only one wildcard character (*), for example, http://*.example.com. Additionally, you can specify only one wildcard character to allow cross-origin access for all origins.
crExposeHeaders :: Lens' CORSRule [Text] Source #
One or more headers in the response that you want users to be able to access from their applications (for example, from a JavaScript XMLHttpRequest object). This element is optional for each rule.
Container
This section describes operations that you can perform on an AWS Elemental MediaStore container.
See: container smart constructor.
container :: Container Source #
Creates a value of Container with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cCreationTime- Unix timestamp.cStatus- The status of container creation or deletion. The status is one of the following:CREATING,ACTIVE, orDELETING. While the service is creating the container, the status isCREATING. When the endpoint is available, the status changes toACTIVE.cARN- The Amazon Resource Name (ARN) of the container. The ARN has the following format: arn:aws:region:that owns this container:containerof container For example: arn:aws:mediastore:us-west-2:111122223333:containermoviescName- The name of the container.cEndpoint- The DNS endpoint of the container. Use the endpoint to identify the specific container when sending requests to the data plane. The service assigns this value when the container is created. Once the value has been assigned, it does not change.
cStatus :: Lens' Container (Maybe ContainerStatus) Source #
The status of container creation or deletion. The status is one of the following: CREATING , ACTIVE , or DELETING . While the service is creating the container, the status is CREATING . When the endpoint is available, the status changes to ACTIVE .
cARN :: Lens' Container (Maybe Text) Source #
The Amazon Resource Name (ARN) of the container. The ARN has the following format: arn:aws:region:that owns this container:containerof container For example: arn:aws:mediastore:us-west-2:111122223333:containermovies